aboutsummaryrefslogtreecommitdiffstatshomepage
path: root/dot_config
diff options
context:
space:
mode:
Diffstat (limited to 'dot_config')
-rw-r--r--dot_config/sway/executable_power-menu.sh10
1 files changed, 6 insertions, 4 deletions
diff --git a/dot_config/sway/executable_power-menu.sh b/dot_config/sway/executable_power-menu.sh
index 4aebcf6..edb5949 100644
--- a/dot_config/sway/executable_power-menu.sh
+++ b/dot_config/sway/executable_power-menu.sh
@@ -1,5 +1,5 @@
#!/bin/sh
# Keyboard-driven power menu via fuzzel --dmenu.
set -eu
choice=$(printf '%s\n' \
@@ -8,12 +8,14 @@ choice=$(printf '%s\n' \
" Logout" \
" Reboot" \
" Poweroff" \
- | fuzzel --dmenu --prompt='power: ' --lines=5 --width=20)
+ | wofi --dmenu --hide-search --prompt='power' \
+ --style "$HOME/.config/wofi/style.css")
case "$choice" in
*Lock) playerctl -a pause; exec swaylock -f -e -c 000000 ;;
*Suspend) playerctl -a pause; exec systemctl suspend ;;
*Logout) exec swaymsg exit ;;
- *Reboot) exec sudo /usr/bin/reboot ;;
- *Poweroff) exec sudo /usr/bin/poweroff ;;
+ *Reboot) exec systemctl reboot ;;
+ *Poweroff) exec systemctl poweroff ;;
esac
+
@@ -1,5 +1,5 @@
#!/bin/sh
-# Keyboard-driven power menu via fuzzel --dmenu.
+# Keyboard-driven power menu via wofi --dmenu (j/k navigation).
set -eu
choice=$(printf '%s\n' \